@@ -1,7 +1,7 @@
 # following PEP 386
-__version__ = "1.2"
+__version__ = "1.2.1"
 
-VERSION = (1, 2)
+VERSION = (1, 2, 1)
 
 # Make sure the ``{% print %}`` is always available, even without a {% load debug_tags %} call.
 # **NOTE** this uses the undocumented, unofficial add_to_builtins() call. It's not promoted
@@ -10,5 +10,5 @@ VERSION = (1, 2)
 # This function is used here nevertheless because the {% print %} tag is a debugging aid,
 # and not a tag that should remain permanently in your templates. Convenience is preferred here.
 #
-from django.template.loader import add_to_builtins
+from django.template.base import add_to_builtins
 add_to_builtins("debugtools.templatetags.debug_tags")
